@@ -498,8 +498,9 @@ class typeFile():
             ret = self.magicObject.buffer(buf).decode('utf-8')
         except (UnicodeDecodeError, AttributeError):
             ret = self.magicObject.buffer(buf)
-            return None
-        return ret
+        if ret:
+            return ret
+        return ''
 
     def getMTypeBuf(self, buf):
         self.magicObject.setflags(self.magic & (~(self.magic&0x4)))
